@@ -1,4 +1,4 @@
-__version__ = '4.0.0'
+__version__ = "5.4.0"
 
 
 from social_core.backends.base import BaseAuth
@@ -9,15 +9,16 @@ from social_core.backends.base import BaseAuth
 # BaseAuth.__init__ to ignore the mandatory strategy argument and load
 # it.
 
+
 def baseauth_init_workaround(original_init):
     def fake_init(self, strategy=None, *args, **kwargs):
         from .utils import load_strategy
+
         original_init(self, strategy or load_strategy(), *args, **kwargs)
+
     return fake_init
 
 
-if not getattr(BaseAuth, '__init_patched', False):
+if not getattr(BaseAuth, "__init_patched", False):
     BaseAuth.__init__ = baseauth_init_workaround(BaseAuth.__init__)
     BaseAuth.__init_patched = True
-
-default_app_config = 'social_django.config.PythonSocialAuthConfig'
